@@ -151,7 +151,7 @@ class Kable:
 
     def enqueueMessage(self, clientId, requestId, req):
         message = {}
-        message['library'] = 'kable-python'
+        message['library'] = 'kable-python-flask'
         message['libraryVersion'] = VERSION
         message['created'] = datetime.utcnow().isoformat()
         message['requestId'] = requestId
